@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "codex-cli" "0.2.1"
+(define-package "codex-cli" "20250913.1900"
   "Codex CLI integration."
   '((emacs "28.1"))
   :url "https://github.com/bennfocus/codex-cli.el"
